# Contributing

## What Is Jekyll

For those unfamiliar with how Jekyll works, check out [jekyll.rb] for all the
details, or read up on the basics of [front matter], [writing posts] and
[creating pages]. Alternatively, just dive in and start editing! After all, the
majority of this site is configuration is just flat text, so it's easy to work
with.

[jekyll.rb]: https://jekyllrb.com/
[front matter]: https://jekyllrb.com/docs/frontmatter/
[writing posts]: https://jekyllrb.com/docs/posts/
[creating pages]: https://jekyllrb.com/docs/pages/

## Development

The prerequisites are [Docker](https://www.docker.com/) and [Docker-compose](https://docs.docker.com/compose/).

If you're on Debian, installing is easy.

Install Docker.

```bash
$ curl -fsSL https://get.docker.com -o get-docker.sh  # have a look if you want
$ CHANNEL=stable sh get-docker.sh
```

Install Docker-compose.

```bash
$ cd autonomic.zone
$ python3 -m venv .venv
$ pip install -r requirements.txt
```

Then fire up the container with the following.

```bash
$ docker-compose up
```

Then visit the locally running website.

> http://localhost:4000

Then you can edit the files as normal and reload the page.

To stop the container when you're done, you can run:

```bash
$ docker-compose stop
```

## Production

Bump the tag in [.drone.yml](./.drone.yml) and [docker-compose.production.yml](./docker-compose.production.yml).

Here's an example git diff. Please update the change log too.

```diff
+++ b/.drone.yml
@@ -10,7 +10,7 @@ steps:
       password:
         from_secret: docker_reg_passwd
       repo: decentral1se/autonomic.zone
-      tags: v2.0.0
+      tags: v3.0.0

   - name: deployment
     image: decentral1se/drone-stack:19.03.8-override-compose

+++ b/docker-compose.production.yml
@@ -3,7 +3,7 @@ version: "3.7"

 services:
   jekyll:
-    image: decentral1se/autonomic.zone:v2.0.0
+    image: decentral1se/autonomic.zone:v3.0.0
     command: jekyll serve --host 0.0.0.0 --trace
     environment:
       JEKYLL_ENV: production
```

Our [drone.autonomic.zone](https://drone.autonomic.zone/autonomic-cooperative/autonomic.zone/) configuration automatically deploys.
